pytorch-igniter
===============

Simplify `pytorch <https://pytorch.org/>`_ training using a configurable wrapper around `pytorch-ignite <https://pytorch.org/ignite/>`_

Installation
-----------------

.. code-block:: bash

  pip install pytorch-igniter

Demo
------

See `pytorch-igniter-demo <https://pytorch-igniter-demo.readthedocs.io/>`_

Documentation
-----------------

View latest documentation at `ReadTheDocs <https://pytorch-igniter.readthedocs.io/>`_

Continuous Integration
------------------------

View continuous integration at `TravisCI <https://travis-ci.org/github/bstriner/pytorch-igniter>`_


PyPI
------------------------

View releases on `PyPI <https://pypi.org/project/pytorch-igniter/>`_


GitHub
------------------------

View source code on `GitHub <https://github.com/bstriner/pytorch-igniter>`_

GitHub tags are automatically released on ReadTheDocs, tested on TravisCI, and deployed to PyPI if successful.

